@@ -20,7 +20,9 @@ class IdealCustomerProfile(BaseModel):
     example_companies: list[ExampleCompany]
     job_titles: list[str]
     keywords: list[str] = None
+    negative_keywords: list[str] = None
     country_codes: list[list[str]] = None
+    employee_country_codes: list[list[str]] = None
     industries: list[str] = None
     company_size_range: CompanySizeRange = None
     company_types: list[str] = None
